Derive the CLSA Social Isolation Index (SII)
Value
A data frame with the same number of rows as df, plus a new column
SII indicating the respondent's social isolation index score.
References
Wister A, Cosco T, Mitchell B, Menec V, Fyffe I. Development and concurrent validity of a composite social isolation index for older adults using the CLSA. Can J Aging. 2019;38(2):180-192. doi:10.1017/S0714980818000612
Canadian Longitudinal Study on Aging. Derived Variables — Social Support Availability (SSA). 2018. https://www.clsa-elcv.ca/wp-content/uploads/2023/06/dv_ssa_11apr2018_v1.1.pdf
Examples
df <- data.frame(
SPA_OUTS = c(3, 3, 2),
SPA_CHRCH = c(3, 5, 5),
SPA_CLUB = c(5, 5, 5),
SPA_EDUC = c(4, 4, 3),
SPA_NEIBR = c(5, 4, 4),
SPA_OTACT = c(4, 3, 3),
SPA_SPORT = c(1, 3, 2),
SPA_VOLUN = c(5, 4, 5),
SN_CHILD_NB = c(2, 4, 0),
SN_FRND_NB = c(0, 0, 7),
SN_NEIBR_NB = c(3, 31, 2),
SN_SIBLIV_NB = c(5, 6, 3),
SN_RELLIV_NB = c(12, 60, 23),
SN_PERWSCH_NB = c(50, 95, 100),
SN_PERCOM_NB = c(0, 0, 0),
SN_PERACT_NB = c(4, 10, 0),
SN_SEECHILD = c(2, 1, NA),
SN_SEESIB = c(2, 3, 4),
SN_SEEREL = c(2, 4, 3),
SN_SEEFRND = c(1, 1, 1),
SN_SEENEIBR = c(2, 2, 6),
SN_LIVH_NB = c(2, 5, 0),
SDC_MRTL = c(2, 2, 1),
SSA_DPAFF = c(100, 100, 50),
SSA_DPEMO = c(62.5, 34.38, 75),
SSA_DPSOC = c(58.33, 83.33, 75),
SSA_DPTNG = c(50, 43.75, 62.5),
DEP_LONLY = c(2, 4, 4),
SPA_MORAC = c(2, 2, 2)
)
derive_sii(df)
#> SPA_OUTS SPA_CHRCH SPA_CLUB SPA_EDUC SPA_NEIBR SPA_OTACT SPA_SPORT SPA_VOLUN
#> 1 3 3 5 4 5 4 1 5
#> 2 3 5 5 4 4 3 3 4
#> 3 2 5 5 3 4 3 2 5
#> SN_CHILD_NB SN_FRND_NB SN_NEIBR_NB SN_SIBLIV_NB SN_RELLIV_NB SN_PERWSCH_NB
#> 1 2 0 3 5 12 50
#> 2 4 0 31 6 60 95
#> 3 0 7 2 3 23 100
#> SN_PERCOM_NB SN_PERACT_NB SN_SEECHILD SN_SEESIB SN_SEEREL SN_SEEFRND
#> 1 0 4 2 2 2 1
#> 2 0 10 1 3 4 1
#> 3 0 0 NA 4 3 1
#> SN_SEENEIBR SN_LIVH_NB SDC_MRTL SSA_DPAFF SSA_DPEMO SSA_DPSOC SSA_DPTNG
#> 1 2 2 2 100 62.50 58.33 50.00
#> 2 2 5 2 100 34.38 83.33 43.75
#> 3 6 0 1 50 75.00 75.00 62.50
#> DEP_LONLY SPA_MORAC SII
#> 1 2 2 3.345306
#> 2 4 2 2.267463
#> 3 4 2 NA